Treibstoff
==========

.. image:: https://img.shields.io/pypi/v/treibstoff.svg
    :target: https://pypi.python.org/pypi/treibstoff
    :alt: Latest PyPI version

Treibstoff contains a set of useful javascript tools for writing browser based
applications (or parts of it).


Detailed Documentation
----------------------

The detailed ``treibstoff`` documentation is available
`here <https://treibstoff.readthedocs.io>`_.


Source Code
-----------

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/conestack/treibstoff>`_.


Copyright
---------

- Copyright (c) 2021-2024 Cone Contributors


Contributors
------------

- Robert Niederreiter (Author)
- Leopold Auersperg-Castell
